pub struct BuildResult {
pub pages: Vec<FeedPage>,
}Expand description
Result of building feeds for a book.
In simple setups this will contain a single rss.xml page. When pagination
is enabled it contains multiple FeedPages (e.g. rss.xml, rss2.xml,
rss3.xml, …) each with a slice of the overall item list.
Fields
pages: Vec<FeedPage>Auto Trait Implementations
impl Freeze for BuildResult
impl RefUnwindSafe for BuildResult
impl Send for BuildResult
impl Sync for BuildResult
impl Unpin for BuildResult
impl UnwindSafe for BuildResult